@@ -11,18 +11,18 @@ settings = conf["notetype"][notetype_name]
 priority = None
 
 
-def update_choices_config():
+def update_list_cloze_config():
     global settings, priority
-    
-    priority = settings.get("priority", 10)
+
+    priority = settings.get("priority", 15)
 
 
-config_updater.append(update_choices_config)
+config_updater.append((update_list_cloze_config, 15))
 
 
-def check(lines: list) -> bool:
-    return lines[0].startswith("- ")
+def check(lines: list, extra_params={}) -> bool:
+    return lines[0].startswith("- ") or lines[0].startswith(r"* ")
 
 
-def get(text: str, deck: str = "Export", tags: list = []):
+def get(text: str, deck: str, tags: list, extra_params={}):
     return cget(text=text, deck=deck, tags=tags)
