@@ -15,21 +15,22 @@ priority = None
 prefix = None
 
 
-def update_choices_config():
+def update_mqa_config():
     global settings, priority, prefix
 
     priority = settings.get("priority", 12)
     prefix = settings.get("prefix", "!")
 
 
-config_updater.append(update_choices_config)
+config_updater.append((update_mqa_config, 10))
 
 
-def check(lines: list) -> bool:
-    return len(lines) >= 2 and lines[0][0] == prefix
+def check(lines: list, extra_params={}) -> bool:
+    return len(lines) >= 3 and len(lines[0]) >= 1 and lines[0][0] == prefix \
+        and len(lines[1]) >= 1 and lines[1][0] == prefix
 
 
-def get(text: str, deck: str = "Export", tags: list = []) -> Note:
+def get(text: str, deck: str, tags: list, extra_params={}) -> Note:
     lines = text.splitlines()
     ind = 0
     while ind < len(lines) and lines[ind][0] == prefix:
